@@ -1014,16 +1014,18 @@ command_rollback(cli::GlobalOptions* global_options, ProxySnappers* snappers, Pr
 	exit(EXIT_FAILURE);
     }
 
-    const string default_description = "rollback backup";
+    const string default_description1 = "rollback backup";
+    const string default_description2 = "writable copy";
 
     bool print_number = false;
 
     SCD scd1;
-    scd1.description = default_description;
+    scd1.description = default_description1;
     scd1.cleanup = "number";
     scd1.userdata["important"] = "yes";
 
     SCD scd2;
+    scd2.description = default_description2;
 
     GetOpts::parsed_opts::const_iterator opt;
 
@@ -1063,7 +1065,7 @@ command_rollback(cli::GlobalOptions* global_options, ProxySnappers* snappers, Pr
 
     ProxySnapshots::iterator previous_default = snapshots.getDefault();
 
-    if (previous_default != snapshots.end() && scd1.description == default_description)
+    if (previous_default != snapshots.end() && scd1.description == default_description1)
         scd1.description += sformat(" of #%d", previous_default->getNum());
 
     ProxySnapshots::const_iterator snapshot1 = snapshots.end();
@@ -1083,6 +1085,10 @@ command_rollback(cli::GlobalOptions* global_options, ProxySnappers* snappers, Pr
 	if (!global_options->quiet())
 	    cout << _("Creating read-write snapshot of current subvolume.") << flush;
 
+	ProxySnapshots::const_iterator active = snapshots.getActive();
+	if (active != snapshots.end() && scd2.description == default_description2)
+	    scd2.description += sformat(" of #%d", active->getNum());
+
 	scd2.read_only = false;
 	snapshot2 = snapper->createSingleSnapshot(snapshots.getCurrent(), scd2);
 
@@ -1104,6 +1110,9 @@ command_rollback(cli::GlobalOptions* global_options, ProxySnappers* snappers, Pr
 	if (!global_options->quiet())
 	    cout << sformat(_("Creating read-write snapshot of snapshot %d."), tmp->getNum()) << flush;
 
+	if (tmp != snapshots.end() && scd2.description == default_description2)
+	    scd2.description += sformat(" of #%d", tmp->getNum());
+
 	scd2.read_only = false;
 	snapshot2 = snapper->createSingleSnapshot(tmp, scd2);
 
